@@ -2,7 +2,7 @@
 readListSDML <- function(x)
 {
   if (is.null(x)) return(NULL)
-  
+
   if (xmlName(x) == "list") {
     ## dimension
     dimension <- readDimensionSDML(x[["dimension"]])
@@ -11,13 +11,16 @@ readListSDML <- function(x)
     attrib <- readProperties(x[["properties"]])
 
     ## fetch sublists
-    thislist <- lapply(xmlChildren(x[["listdata"]]), readListSDML)
+    thislist <- xmlChildren(x[["listdata"]])
+    thislist <- thislist[sapply(thislist[seq_along(thislist)],
+                                xmlName) != "text"]
+    thislist <- lapply(thislist, readListSDML)
     if (!length(thislist)) return(thislist)
-      
+
     ## set names:
     ### no names for arrays
     if(any(names(thislist) == "array")) names(thislist) <- NULL
-        
+
     ### list with dim attribute?
     if(length(dimension$dim) > 1) {
       dim(thislist) <- dimension$dim
@@ -26,15 +29,15 @@ readListSDML <- function(x)
     ### only one dimension?
       if(length(dimension$names[[1]]) > 0)
         names(thislist) <- dimension$names[[1]]
-    
+
     ## set/append properties
     atL <- attributes(thislist)
     if (!is.null(atL)) attrib <- c(attrib, atL)
     if (!is.null(attrib)) attributes(thislist) <- attrib
-    
+
     return(thislist)
   }
-    
+
   if (xmlName(x) == "array")
     return(readArraySDML(x))
 
